@@ -287,9 +287,7 @@ if __name__ == "__main__":
                     [imp_nmf_proxy, None],
                     [imp_nmf_proxy_mean_first, None]]
         imp_name = "RandomBlockMatrices_2"
-        wh_name = rng.generate_wh_name(w_size, h_size, nb_clusters,
-                                       min_corr, max_corr, eps, rnd_norms,
-                                       )
+        wh_name = rng.generate_wh_name(w_size, h_size, nb_clusters, min_corr, max_corr, eps, rnd_norms)
         imp_tester = imp.ImputerTester(mat=gen_M, name=f"{imp_name}_{wh_name}",
                                        imputer=imp_nmf_proxy, ref_clst=None,
                                        clst=None, err_func="MSE")
@@ -321,13 +319,13 @@ if __name__ == "__main__":
                                                                          n_obs=w_size, h_icorr_min=min_corr,
                                                                          h_icorr_max=max_corr,
                                                                          random_norms=random_norms, epsilon=eps,
-                                                                         wclust_factor=wclust_factor)
+                                                                         avg_w_clust=wclust_factor)
         for censor_indices in censor_indices_list:
 
             utl.censor_data(mat=gen_m, censored_indices=censor_indices, inplace=True)
             rnstr = "RandNorms" if random_norms else "ConstNorms"
-            wh_name = rng.generate_wh_name(w_size, h_size, nb_clusters,
-                                           min_corr, max_corr, eps, random_norms, censor_indices)
+            wh_name = rng.generate_wh_name(w_size, h_size, nb_clusters, min_corr, max_corr, eps, random_norms,
+                                           censor_indices)
             # wh_name = f"M{w_size}x{h_size}_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
             #           f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_indices}.csv"
             gen_m.to_csv(res_path / "random_nmf" / wh_name,
